package env

import (
	"fmt"
	"os"
)

func init() {
	AppName = GetEnvDefault("APP_NAME", "default")
	Namespace = GetEnvDefault("NAMESPACE", "default")
	AppType = SAppType(GetEnvDefault("APP_TYPE", string(AppTypeAPI)))
}

var AppName string
var Namespace string
var AppType SAppType

type SAppType string

const (
	AppTypeAPI     = SAppType("api")     // api应用类型
	AppTypeService = SAppType("service") // service应用类型
)

func GetEnvDefault(key, defVal string) string {
	val, ex := os.LookupEnv(key)
	if !ex {
		os.Setenv(key, defVal)
		return defVal
	}
	return val
}

// GetAppNameWithType 获取带应用类型的应用名
func GetAppNameWithType() string {
	return fmt.Sprintf("%s-%s", AppType, AppName)
}
